## v0.6.3 (2025-06-22)

### Fix

- **docker**: run ezbak directly

## v0.6.2 (2025-06-22)

### Fix

- **docker**: improve docker load speed

## v0.6.1 (2025-06-21)

### Fix

- **docker**: reduce cpu usage

## v0.6.0 (2025-06-21)

### Feat

- **cli**: add restore command

## v0.5.0 (2025-06-21)

### Feat

- **logging**: support logger prefix (#9)
- add docker container (#8)
- rename restore method to restore_latest_backup (#7)
- **restore**: add option to pre-clean restore directory (#6)
- add exclude list of files (#2)

### Fix

- rename arguments for clarity (#5)

### Refactor

- use a global settings object (#4)

## v0.4.0 (2025-06-17)

### Feat

- rename files with and without time labels

## v0.3.0 (2025-06-17)

### Feat

- **restore**: change ownership of restored files

## v0.2.1 (2025-06-16)

### Fix

- accept strings or Path for logfile location

## v0.2.0 (2025-06-16)

### Feat

- initial commit
